@@ -14,7 +14,7 @@
 //!
 //! ```toml
 //! [dependencies]
-//! kmip-ttlv = "0.3.0"
+//! kmip-ttlv = "0.3.1"
 //! serde = "1.0.126"
 //! serde_derive = "1.0.126"
 //! ```
@@ -48,6 +48,24 @@
 //!
 //! To learn more about the low-level API see the [types] module.
 //!
+//! ## Async API
+//!
+//! This crate also supports _deserialization_ from an async reader via the feature flags `async-with-async-std` and
+//! `async-with-tokio`. Only one of these flags can be specified at once and neither can be mixed with the default
+//! 'sync' feature flag. The example below also enables the high level API which is disabled otherwise when you
+//! use `default-features = false`.
+//!
+//! ```toml
+//! [dependencies.kmip-ttlv]
+//! version = "0.3.1"
+//! default-features = false
+//! features = ["async-with-async-std", "high-level"]
+//! ```
+//!
+//! Without an async feature enabled you can only pass something that implements the `Read` trait to [de::from_reader].
+//!
+//! With an async feature enabled you can pass something that implements `async_std::io::ReadExt` or `tokio::io::AsyncReadExt`.
+//!
 //! # TTLV format
 //!
 //! TTLV stands for Tag-Type-Length-Value which represents the format of each node in a tree when serialized to bytes:
@@ -220,6 +238,17 @@
 //! For logging or storing of requests and responses for later diagnostic purposes use the
 //! [PrettyPrinter::to_diag_string()] function to render TTLV bytes in a compact textual representation with most
 //! values redacted (only enumeration values are included in the generated string).
+#[cfg(all(
+    feature = "sync",
+    any(feature = "async-with-async-std", feature = "async-with-tokio")
+))]
+compile_error!("feature \"sync\" cannot be enabled at the same time as either of the \"async-with-async-std\" or \"async-with-tokio\" features");
+
+#[cfg(all(feature = "async-std", not(feature = "async-with-async-std")))]
+compile_error!("do not enable the \"async-std\" feature directly, instead enable the \"async-with-async-std\" feature");
+
+#[cfg(all(feature = "tokio", not(feature = "async-with-tokio")))]
+compile_error!("do not enable the \"tokio\" feature directly, instead enable the \"async-with-tokio\" feature");
 
 #[cfg(feature = "high-level")]
 #[macro_use]
@@ -231,6 +260,8 @@ pub mod de;
 pub mod error;
 #[cfg(feature = "high-level")]
 pub mod ser;
+#[cfg(feature = "high-level")]
+pub mod traits;
 pub mod types;
 #[cfg(feature = "high-level")]
 pub mod util;
